summaryrefslogtreecommitdiffstats
path: root/src/electronics/switch.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/electronics/switch.h')
-rw-r--r--src/electronics/switch.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/src/electronics/switch.h b/src/electronics/switch.h
index 40247c9..17fd493 100644
--- a/src/electronics/switch.h
+++ b/src/electronics/switch.h
@@ -11,21 +11,22 @@
#ifndef SWITCH_H
#define SWITCH_H
-#include <qguardedptr.h>
-#include <qobject.h>
+#include <tqguardedptr.h>
+#include <tqobject.h>
class CircuitDocument;
class Component;
class Pin;
class Resistance;
-class QTimer;
+class TQTimer;
/**
@author David Saxton
*/
-class Switch : public QObject
+class Switch : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
enum State
@@ -34,7 +35,7 @@ class Switch : public QObject
Closed,
};
- Switch( Component * parent, Pin * p1, Pin * p2, State state );
+ Switch( Component * tqparent, Pin * p1, Pin * p2, State state );
~Switch();
/**
* If bouncing has been set to true, then the state will not switch
@@ -63,7 +64,7 @@ class Switch : public QObject
protected slots:
/**
* Called from a QTimer timeout - our bouncing period has come to an
* end. This will then fully disconnect or connect the pins depending
* on the current state.
*/
@@ -78,9 +79,9 @@ class Switch : public QObject
Resistance * m_pBounceResistance;
State m_state;
Component * m_pComponent;
- QGuardedPtr<Pin> m_pP1;
- QGuardedPtr<Pin> m_pP2;
- QTimer * m_pStopBouncingTimer;
+ TQGuardedPtr<Pin> m_pP1;
+ TQGuardedPtr<Pin> m_pP2;
+ TQTimer * m_pStopBouncingTimer;
};
#endif
@@ -63,7 +64,7 @@ class Switch : public QObject
protected slots:
/**
- * Called from a QTimer timeout - our bouncing period has come to an
+ * Called from a TQTimer timeout - our bouncing period has come to an
* end. This will then fully disconnect or connect the pins depending
* on the current state.